'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _liskElements = require('lisk-elements');

var _liskElements2 = _interopRequireDefault(_liskElements);

var _command = require('@oclif/command');

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _transactions = require('../../utils/transactions');

var _transactions2 = _interopRequireDefault(_transactions);

var _utils = require('../../utils/input/utils');

var _error = require('../../utils/error');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const secondPublicKeyDescription = `Specifies a source for providing a second public key to the command. The second public key must be provided via this option. Sources must be one of \`file\` or \`stdin\`. In the case of \`file\`, a corresponding identifier must also be provided.

	Note: if both transaction and second public key are passed via stdin, the transaction must be the first line.

	Examples:
	- --second-public-key file:/path/to/my/message.txt
	- --second-public-key 790049f919979d5ea42cca7b7aa0812cbae8f0db3ee39c1fe3cef18e25b67951
`;

const getTransactionInput = async () => {
	try {
		const { data } = await (0, _utils.getStdIn)({ dataIsRequired: true });
		if (!data) {
			throw new _error.ValidationError('No transaction was provided.');
		}
		return data;
	} catch (e) {
		throw new _error.ValidationError('No transaction was provided.');
	}
};

const processSecondPublicKey = async secondPublicKey => secondPublicKey.includes(':') ? (0, _utils.getData)(secondPublicKey) : secondPublicKey;

class VerifyCommand extends _base2.default {
	async run() {
		const {
			args: { transaction },
			flags: { 'second-public-key': secondPublicKeySource }
		} = this.parse(VerifyCommand);

		const transactionInput = transaction || (await getTransactionInput());
		const transactionObject = (0, _transactions2.default)(transactionInput);

		const secondPublicKey = secondPublicKeySource ? await processSecondPublicKey(secondPublicKeySource) : null;

		const verified = _liskElements2.default.transaction.utils.verifyTransaction(transactionObject, secondPublicKey);
		this.print({ verified });
	}
}

exports.default = VerifyCommand;
VerifyCommand.args = [{
	name: 'transaction',
	description: 'Transaction to verify in JSON format.'
}];

VerifyCommand.flags = Object.assign({}, _base2.default.flags, {
	'second-public-key': _command.flags.string({
		name: 'Second public key',
		description: secondPublicKeyDescription
	})
});

VerifyCommand.description = `
Verifies a transaction has a valid signature.
`;

VerifyCommand.examples = ['transaction:verify \'{"type":0,"amount":"100",...}\'', 'transaction:verify \'{"type":0,"amount":"100",...}\' --second-public-key=647aac1e2df8a5c870499d7ddc82236b1e10936977537a3844a6b05ea33f9ef6'];