'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getConfig = exports.setConfig = undefined;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lockfile = require('lockfile');

var _lockfile2 = _interopRequireDefault(_lockfile);

var _default_config = require('../../default_config.json');

var _default_config2 = _interopRequireDefault(_default_config);

var _constants = require('./constants');

var _error = require('./error');

var _fs3 = require('./fs');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const configFileName = 'config.json'; /*
                                       * LiskHQ/lisk-commander
                                       * Copyright © 2017–2018 Lisk Foundation
                                       *
                                       * See the LICENSE file at the top-level directory of this distribution
                                       * for licensing information.
                                       *
                                       * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                       * no part of this software, including this file, may be copied, modified,
                                       * propagated, or distributed except according to the terms contained in the
                                       * LICENSE file.
                                       *
                                       * Removal or modification of this copyright notice is prohibited.
                                       *
                                       */

const lockfileName = 'config.lock';

const fileWriteErrorMessage = filePath => `Could not write to \`${filePath}\`. Your configuration will not be persisted.`;

const attemptCallWithError = (fn, errorMessage) => {
	try {
		return fn();
	} catch (_) {
		throw new Error(errorMessage);
	}
};

const attemptToCreateDir = dirPath => {
	const fn = _fs2.default.mkdirSync.bind(null, dirPath);
	return attemptCallWithError(fn, fileWriteErrorMessage(dirPath));
};

const attemptToCreateFile = filePath => {
	const fn = _fs3.writeJSONSync.bind(null, filePath, _default_config2.default);
	return attemptCallWithError(fn, fileWriteErrorMessage(filePath));
};

const checkLockfile = filePath => {
	const locked = _lockfile2.default.checkSync(filePath);
	const errorMessage = `Config lockfile at ${filePath} found. Are you running Lisk Commander in another process?`;
	if (locked) {
		throw new Error(errorMessage);
	}
};

const attemptToReadJSONFile = filePath => {
	const fn = _fs3.readJSONSync.bind(null, filePath);
	const errorMessage = `Config file cannot be read or is not valid JSON. Please check ${filePath} or delete the file so we can create a new one from defaults.`;
	return attemptCallWithError(fn, errorMessage);
};

const attemptToValidateConfig = (config, filePath) => {
	const rootKeys = _constants.CONFIG_VARIABLES.map(key => key.split('.')[0]);
	const fn = () => rootKeys.forEach(key => {
		if (!Object.keys(config).includes(key)) {
			throw new _error.ValidationError(`Key ${key} not found in config file.`);
		}
	});
	const errorMessage = `Config file seems to be corrupted: missing required keys. Please check ${filePath} or delete the file so we can create a new one from defaults.`;
	return attemptCallWithError(fn, errorMessage);
};

const setConfig = exports.setConfig = (configDirPath, newConfig) => {
	const lockFilePath = _path2.default.join(configDirPath, lockfileName);
	const configFilePath = _path2.default.join(configDirPath, configFileName);

	checkLockfile(lockFilePath);
	_lockfile2.default.lockSync(lockFilePath);
	try {
		(0, _fs3.writeJSONSync)(configFilePath, newConfig);
		return true;
	} catch (e) {
		return false;
	} finally {
		_lockfile2.default.unlockSync(lockFilePath);
	}
};

const getConfig = exports.getConfig = configDirPath => {
	if (!_fs2.default.existsSync(configDirPath)) {
		attemptToCreateDir(configDirPath);
	}

	const configFilePath = _path2.default.join(configDirPath, configFileName);

	if (!_fs2.default.existsSync(configFilePath)) {
		attemptToCreateFile(configFilePath);
		return _default_config2.default;
	}

	const config = attemptToReadJSONFile(configFilePath);
	attemptToValidateConfig(config, configFilePath);

	return config;
};